@@ -1,18 +1,21 @@
 import logging
 from typing import Dict
 
-from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import \
-    ACICacheHandlerABC
-from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import \
-    ACIUpdateDateTupleABC
+from peek_abstract_chunked_index.private.client.handlers.ACICacheHandlerABC import (
+    ACICacheHandlerABC,
+)
+from peek_abstract_chunked_index.private.tuples.ACIUpdateDateTupleABC import (
+    ACIUpdateDateTupleABC,
+)
 from peek_plugin_graphdb._private.PluginNames import graphDbFilt
-from peek_plugin_graphdb._private.tuples.ItemKeyIndexUpdateDateTuple import \
-    ItemKeyIndexUpdateDateTuple
+from peek_plugin_graphdb._private.tuples.ItemKeyIndexUpdateDateTuple import (
+    ItemKeyIndexUpdateDateTuple,
+)
 
 logger = logging.getLogger(__name__)
 
 clientItemKeyIndexWatchUpdateFromDeviceFilt = {
-    'key': "clientItemKeyIndexWatchUpdateFromDevice"
+    "key": "clientItemKeyIndexWatchUpdateFromDevice"
 }
 clientItemKeyIndexWatchUpdateFromDeviceFilt.update(graphDbFilt)
 
