@@ -3,9 +3,9 @@ from .SettingPropertyHandler import makeSettingPropertyHandler
 from .ViewSegmentHandler import makeSegmentTableHandler
 
 
-def makeAdminBackendHandlers(tupleObservable: TupleDataObservableHandler,
-                             dbSessionCreator):
+def makeAdminBackendHandlers(
+    tupleObservable: TupleDataObservableHandler, dbSessionCreator
+):
     yield makeSegmentTableHandler(tupleObservable, dbSessionCreator)
 
     yield makeSettingPropertyHandler(dbSessionCreator)
-
