@@ -7,13 +7,14 @@ from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
 
 @addTupleType
 class GraphDbTraceResultEdgeTuple(Tuple):
-    """ GraphDB Trace Result Edge Tuple
+    """GraphDB Trace Result Edge Tuple
 
     This tuple contains the result of running a trace on the model
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbTraceResultEdgeTuple'
-    __rawJonableFields__ = ('key', 'srcVertexKey', 'dstVertexKey', 'props')
+
+    __tupleType__ = graphDbTuplePrefix + "GraphDbTraceResultEdgeTuple"
+    __rawJonableFields__ = ("key", "srcVertexKey", "dstVertexKey", "props")
 
     #:  The key of edge
     key: str = TupleField()
