@@ -3,22 +3,29 @@ from typing import List, Optional
 from vortex.Tuple import Tuple, addTupleType, TupleField
 
 from peek_plugin_graphdb._private.PluginNames import graphDbTuplePrefix
-from peek_plugin_graphdb.tuples.GraphDbTraceResultEdgeTuple import \
-    GraphDbTraceResultEdgeTuple
-from peek_plugin_graphdb.tuples.GraphDbTraceResultVertexTuple import \
-    GraphDbTraceResultVertexTuple
+from peek_plugin_graphdb.tuples.GraphDbTraceResultEdgeTuple import (
+    GraphDbTraceResultEdgeTuple,
+)
+from peek_plugin_graphdb.tuples.GraphDbTraceResultVertexTuple import (
+    GraphDbTraceResultVertexTuple,
+)
 
 
 @addTupleType
 class GraphDbTraceResultTuple(Tuple):
-    """ GraphDB Trace Result Tuple
+    """GraphDB Trace Result Tuple
 
     This tuple contains the result of running a trace on the model
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbTraceResultTuple'
-    __rawJonableFields__ = ('modelSetKey', 'traceConfigKey',
-                            'startVertexKey', 'traceAbortedMessage')
+
+    __tupleType__ = graphDbTuplePrefix + "GraphDbTraceResultTuple"
+    __rawJonableFields__ = (
+        "modelSetKey",
+        "traceConfigKey",
+        "startVertexKey",
+        "traceAbortedMessage",
+    )
 
     #:  The key of the model set that the result was created with.
     modelSetKey: str = TupleField()
